import createExpressApp from "express"
import { listen } from "listhen"
import { WebSocketServer } from "ws"
import { appRouter } from "./trpc"
import { createExpressMiddleware as createTrpcMiddleware } from "@trpc/server/adapters/express"
import { applyWSSHandler } from "@trpc/server/adapters/ws"
import { seedDatabase } from "./seed"
import { createContext } from "./trpc/base"

const expressApp = createExpressApp()

expressApp.use("/trpc", createTrpcMiddleware({
	router: appRouter,
	createContext
}))

await seedDatabase()
const { server } = await listen(expressApp)

const wss = new WebSocketServer({ server, path: "/ws" })
const wssTrpcHandler = applyWSSHandler({ wss, createContext, router: appRouter })

process.on("SIGTERM", () => {
	console.log("Received SIGTERM")
	wssTrpcHandler.broadcastReconnectNotification()
	wss.close()
})
